========
Examples
========

The LilyPond documentation used in example can be downloaded here:
:download:`/_scores/minuet-in-g.ly`.

Original paper size
===================

.. example:: _

   .. lilyinclude:: /_scores/minuet-in-g.ly
      :nocrop:
 
Disable Audio
=============

.. example:: _

   .. lilyinclude:: /_scores/minuet-in-g.ly
      :noaudio:

Transposing
===========

.. example:: _

   .. lilyinclude:: /_scores/minuet-in-g.ly
      :transpose: g c

Multiple Pages
==============

.. example:: _

   .. lilyinclude:: /_scores/alice.ly

Loop
====

.. example:: _

   .. lilyinclude:: /_scores/minuet-in-g.ly
      :loop:

.. versionadded:: 1.2

Control Bar at the Top
======================

.. example:: _

   .. lilyinclude:: /_scores/minuet-in-g.ly
      :controls: top

.. versionadded:: 1.3

Jianpu (Numbered Musical Notation)
==================================

.. example:: _

   .. jianpu::

      title=C Major Scale
      1=C
      4=60
      2/4

      1 2 3 4 5 6 7 1'

.. seealso:: :ref:`jianpu-directive`.

.. versionadded:: 1.5
